@@ -6,9 +6,19 @@ package "misc" or "util" seemed afraught with namespace collisions.
 """
 import os, sys, json
 
-w3 = None
+w3, private, public = None, None, None
 
-version = '1.1.14'
+def set_private(x):
+    global private
+    private = x
+    pass
+
+def set_public(x):
+    global public
+    public = x
+    pass
+
+version = '1.3.0'
 
 def w3_connect(default_account):
     global w3
@@ -53,7 +63,19 @@ def load_contractAddress(name):
 def save_contractAddress(name, contractAddress):
     return           open(f'out/{name}.cta','w').write(contractAddress)
 
-def deploy_contractAddress(name, *args):
+def load_contract(name, address=None):
+    if address is None:
+        address = load_contractAddress(name)
+        pass
+    abi        = load_abi(name)
+    contract   = w3.eth.contract(abi=abi, address=address)
+    return contract
+
+def load_wrapped_contract(name, address=None):
+    contract = load_contract(name, address)
+    return  WrapContract(contract)
+
+def old_deploy_contractAddress(name, *args):
     abi        = load_abi(name)
     bytecode   = load_bytecode(name)
     contract   = w3.eth.contract(abi=abi, bytecode=bytecode)
@@ -63,6 +85,21 @@ def deploy_contractAddress(name, *args):
     save_contractAddress(name, contractAddress)
     return contractAddress
 
+def deploy_contractAddress(name, *args):
+    if private is None:
+        return old_deploy_contractAddress(name, *args)
+    abi        = load_abi(name)
+    bytecode   = load_bytecode(name)
+    contract   = w3.eth.contract(abi=abi, bytecode=bytecode)
+    txn        = contract.constructor(*args).buildTransaction(
+        nonce = w3.eth.get_transaction_count(public))
+    signed_txn = w3.eth.account.sign_transaction(txn, private)
+    tx_hash = w3.eth.send_raw_transaction(signed_txn.rawTransaction)
+    tx_receipt = wait_for_tx(tx_hash)
+    contractAddress = tx_receipt.contractAddress
+    save_contractAddress(name, contractAddress)
+    return contractAddress
+
 def get_default_address():
     return w3.eth.default_account
 
@@ -81,13 +118,25 @@ class WrapMixin:
 def get_func(contract, funcname):
     return contract.functions.__dict__[funcname]
 
-def wcall(contract, funcname, *args, _from=None, **kw):
+def old_wcall(contract, funcname, *args, _from=None, **kw):
     if _from: kw['from'] = _from
     func = get_func(contract, funcname)
     tx_hash = func(*args).transact(kw)
     tx_receipt = wait_for_tx(tx_hash)
     return tx_receipt
 
+def wcall(contract, funcname, *args, _from=None, **kw):
+    if private is None:
+        return old_wcall(contract, funcname, *args, _from, **kw)
+    if _from: kw['from'] = _from
+    func = get_func(contract, funcname)
+    kw['nonce'] = w3.eth.get_transaction_count(public)
+    txn = func(*args).buildTransaction(kw)
+    signed_txn = w3.eth.account.sign_transaction(txn, private)
+    tx_hash = w3.eth.send_raw_transaction(signed_txn.rawTransaction)
+    tx_receipt = wait_for_tx(tx_hash)
+    return tx_receipt
+
 def rcall(contract, funcname, *args, **kw):
     func = get_func(contract, funcname)
     return func(*args).call(kw)
